@@ -141,6 +141,7 @@ class InstallUndercloud(command.Command):
         return parser
 
     def take_action(self, parsed_args):
+        output_dir = utils.get_output_dir(self.osloconfig.get('output_dir'))
         # Fetch configuration used to add logging to a file
         utils.load_config(self.osloconfig, constants.UNDERCLOUD_CONF_PATH)
         utils.configure_logging(self.log, self.app_args.verbose_level,
@@ -166,7 +167,7 @@ class InstallUndercloud(command.Command):
                 subprocess.check_call(cmd)
                 self.log.warning(UNDERCLOUD_COMPLETION_MESSAGE.format(
                     os.path.join(
-                        constants.UNDERCLOUD_OUTPUT_DIR,
+                        output_dir,
                         'tripleo-undercloud-passwords.yaml'
                     ),
                     '~/stackrc'
@@ -213,12 +214,12 @@ class UpgradeUndercloud(InstallUndercloud):
                 " ".join(cmd)))
 
     def _run_upgrade(self, parsed_args):
+        output_dir = utils.get_output_dir(self.osloconfig.get('output_dir'))
         cmd = undercloud_config.\
             prepare_undercloud_deploy(
                 upgrade=True,
                 yes=parsed_args.yes,
-                no_validations=parsed_args.
-                no_validations,
+                no_validations=parsed_args.no_validations,
                 verbose_level=self.app_args.verbose_level,
                 reproduce_command=parsed_args.reproduce_command,
                 force_stack_update=parsed_args.force_stack_update)
@@ -228,7 +229,7 @@ class UpgradeUndercloud(InstallUndercloud):
             self.log.warning(
                 UNDERCLOUD_UPGRADE_COMPLETION_MESSAGE.format(
                     os.path.join(
-                        constants.UNDERCLOUD_OUTPUT_DIR,
+                        output_dir,
                         'tripleo-undercloud-passwords.yaml'
                     ),
                     '~/stackrc'))
